@@ -2,14 +2,12 @@
 
 __author__ = """Mika Pflüger"""
 __email__ = "mika.pflueger@pik-potsdam.de"
-# fmt: off
-# bump2version wants single quotes
-__version__ = '0.2.0'
-# fmt: on
+__version__ = "0.3.1"
 
-import pint
 import pint_xarray
 
-from . import _accessors
+from . import accessors
 from ._data_format import open_dataset
 from ._units import ureg
+
+__all__ = ["accessors", "open_dataset", "ureg"]
